@@ -78,7 +78,7 @@ class Occupancy:
                         tz_str = building['data']['getBuilding']['timeZone']
                         if not tz_str:
                             raise AssertionError(f'length for time zone {len(tz_str)} is not correct.')
-                        df.index = df.index.tz_localize(None).tz_localize(tz_str)
+                        df.index = df.index.tz_localize(None).tz_localize(tz_str, nonexistent='shift_forward')
                     except TypeError:
                         self.log.error("getting error in dataframe portion")
                 else:
